<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="es" sourcelanguage="en">
<context>
    <name>CopyEngine</name>
    <message>
        <location filename="../../CopyEngine.cpp" line="442"/>
        <location filename="../../CopyEngine.cpp" line="465"/>
        <source>The engine is forced to move, you can&apos;t copy with it</source>
        <translation>El motor se ve obligado a moverse, no se puede copiar con ella</translation>
    </message>
    <message>
        <location filename="../../CopyEngine.cpp" line="519"/>
        <location filename="../../CopyEngine.cpp" line="542"/>
        <source>The engine is forced to copy, you can&apos;t move with it</source>
        <translation>El motor se ve obligado a copiar, no te puedes mover con él</translation>
    </message>
    <message>
        <location filename="../../CopyEngine.cpp" line="566"/>
        <source>Destination</source>
        <translation>Destino</translation>
    </message>
    <message>
        <location filename="../../CopyEngine.cpp" line="566"/>
        <source>Use the actual destination &quot;%1&quot;?</source>
        <translation>Utilice el destino &quot;%1&quot; actual?</translation>
    </message>
    <message>
        <location filename="../../CopyEngine.cpp" line="731"/>
        <source>The mode has been forced previously. This is an internal error, please report it</source>
        <translation>El modo se ha visto obligado previamente. Este es un error interno, por favor repórtelo</translation>
    </message>
    <message>
        <location filename="../../CopyEngine.cpp" line="886"/>
        <source>Supported only on Windows</source>
        <translation>Compatible solo con Windows</translation>
    </message>
    <message>
        <location filename="../../CopyEngine.cpp" line="1035"/>
        <location filename="../../CopyEngine.cpp" line="1038"/>
        <location filename="../../CopyEngine.cpp" line="1043"/>
        <location filename="../../CopyEngine.cpp" line="1047"/>
        <source>Ask</source>
        <translation>Pedir</translation>
    </message>
    <message>
        <location filename="../../CopyEngine.cpp" line="1036"/>
        <location filename="../../CopyEngine.cpp" line="1040"/>
        <location filename="../../CopyEngine.cpp" line="1044"/>
        <location filename="../../CopyEngine.cpp" line="1048"/>
        <source>Skip</source>
        <translation>Omitir</translation>
    </message>
    <message>
        <location filename="../../CopyEngine.cpp" line="1039"/>
        <source>Merge</source>
        <translation>Unir</translation>
    </message>
    <message>
        <location filename="../../CopyEngine.cpp" line="1041"/>
        <location filename="../../CopyEngine.cpp" line="1053"/>
        <source>Rename</source>
        <translation>Cambiar el nombre</translation>
    </message>
    <message>
        <location filename="../../CopyEngine.cpp" line="1045"/>
        <source>Put at the end</source>
        <translation>Ponga al final</translation>
    </message>
    <message>
        <location filename="../../CopyEngine.cpp" line="1049"/>
        <source>Overwrite</source>
        <translation>Sobrescribir</translation>
    </message>
    <message>
        <location filename="../../CopyEngine.cpp" line="1050"/>
        <source>Overwrite if different</source>
        <translation>Sobrescribir si es diferente</translation>
    </message>
    <message>
        <location filename="../../CopyEngine.cpp" line="1051"/>
        <source>Overwrite if newer</source>
        <translation>Sobrescribir si nuevo</translation>
    </message>
    <message>
        <location filename="../../CopyEngine.cpp" line="1052"/>
        <source>Overwrite if older</source>
        <translation>Sobrescribir si es mayor</translation>
    </message>
    <message>
        <location filename="../../CopyEngine.cpp" line="1123"/>
        <source>Options error</source>
        <translation>error Opciones</translation>
    </message>
    <message>
        <location filename="../../CopyEngine.cpp" line="1123"/>
        <source>Options engine is not loaded. Unable to access the filters</source>
        <translation>Opciones del motor no está cargado. No es posible acceder a los filtros</translation>
    </message>
</context>
<context>
    <name>CopyEngineFactory</name>
    <message>
        <location filename="../../CopyEngineFactory.cpp" line="60"/>
        <location filename="../../CopyEngineFactory.cpp" line="309"/>
        <source>Supported only on Windows</source>
        <translation>Compatible solo con Windows</translation>
    </message>
    <message>
        <location filename="../../CopyEngineFactory.cpp" line="436"/>
        <location filename="../../CopyEngineFactory.cpp" line="439"/>
        <location filename="../../CopyEngineFactory.cpp" line="444"/>
        <location filename="../../CopyEngineFactory.cpp" line="448"/>
        <source>Ask</source>
        <translation>Pedir</translation>
    </message>
    <message>
        <location filename="../../CopyEngineFactory.cpp" line="437"/>
        <location filename="../../CopyEngineFactory.cpp" line="441"/>
        <location filename="../../CopyEngineFactory.cpp" line="445"/>
        <location filename="../../CopyEngineFactory.cpp" line="449"/>
        <source>Skip</source>
        <translation>Omitir</translation>
    </message>
    <message>
        <location filename="../../CopyEngineFactory.cpp" line="440"/>
        <source>Merge</source>
        <translation>Unir</translation>
    </message>
    <message>
        <location filename="../../CopyEngineFactory.cpp" line="442"/>
        <location filename="../../CopyEngineFactory.cpp" line="454"/>
        <source>Rename</source>
        <translation>Cambiar el nombre</translation>
    </message>
    <message>
        <location filename="../../CopyEngineFactory.cpp" line="446"/>
        <source>Put at the end</source>
        <translation>Ponga al final</translation>
    </message>
    <message>
        <location filename="../../CopyEngineFactory.cpp" line="450"/>
        <source>Overwrite</source>
        <translation>Sobrescribir</translation>
    </message>
    <message>
        <location filename="../../CopyEngineFactory.cpp" line="451"/>
        <source>Overwrite if different</source>
        <translation>Sobrescribir si es diferente</translation>
    </message>
    <message>
        <location filename="../../CopyEngineFactory.cpp" line="452"/>
        <source>Overwrite if newer</source>
        <translation>Sobrescribir si nuevo</translation>
    </message>
    <message>
        <location filename="../../CopyEngineFactory.cpp" line="453"/>
        <source>Overwrite if older</source>
        <translation>Sobrescribir si es mayor</translation>
    </message>
    <message>
        <location filename="../../CopyEngineFactory.cpp" line="469"/>
        <location filename="../../CopyEngineFactory.cpp" line="508"/>
        <source>Options error</source>
        <translation>error Opciones</translation>
    </message>
    <message>
        <location filename="../../CopyEngineFactory.cpp" line="469"/>
        <source>Options engine is not loaded. Unable to access the filters</source>
        <translation>Opciones del motor no está cargado. No es posible acceder a los filtros</translation>
    </message>
    <message>
        <location filename="../../CopyEngineFactory.cpp" line="508"/>
        <source>Options engine is not loaded, can&apos;t access to the filters</source>
        <translation>Opciones del motor no está cargado, no se puede acceder a los filtros</translation>
    </message>
</context>
<context>
    <name>DiskSpace</name>
    <message>
        <location filename="../../DiskSpace.ui" line="14"/>
        <source>Disk space</source>
        <translation>Espacio en disco</translation>
    </message>
    <message>
        <location filename="../../DiskSpace.ui" line="24"/>
        <source>You need more space on this drive to finish this transfer</source>
        <translation>Necesita más espacio en esta unidad para terminar esta transferencia</translation>
    </message>
    <message>
        <location filename="../../DiskSpace.ui" line="49"/>
        <source>Continue</source>
        <translation>Continuar</translation>
    </message>
    <message>
        <location filename="../../DiskSpace.ui" line="56"/>
        <source>Cancel</source>
        <translation>Cancelar</translation>
    </message>
    <message>
        <location filename="../../DiskSpace.cpp" line="23"/>
        <source>Drives %1 have %2 available but need %3</source>
        <translation>Drives %1 tienen %2 disponible, pero necesitan %3</translation>
    </message>
</context>
<context>
    <name>FileErrorDialog</name>
    <message>
        <location filename="../../FileErrorDialog.cpp" line="92"/>
        <source>Error on folder</source>
        <translation>Error en la carpeta</translation>
    </message>
    <message>
        <location filename="../../FileErrorDialog.cpp" line="95"/>
        <source>Folder name</source>
        <translation>Nombre de la carpeta</translation>
    </message>
</context>
<context>
    <name>FileExistsDialog</name>
    <message>
        <location filename="../../FileExistsDialog.cpp" line="201"/>
        <source>%name% - copy%suffix%</source>
        <translation>%name% - copia%suffix%</translation>
    </message>
    <message>
        <location filename="../../FileExistsDialog.cpp" line="208"/>
        <source>%name% - copy (%number%)%suffix%</source>
        <translation>%name% - copia (%number%)%suffix%</translation>
    </message>
    <message>
        <location filename="../../FileExistsDialog.cpp" line="299"/>
        <source>Error</source>
        <translation>Error</translation>
    </message>
    <message>
        <location filename="../../FileExistsDialog.cpp" line="299"/>
        <source>Try rename with using special characters</source>
        <translation>Trate de cambiar el nombre con el uso de caracteres especiales</translation>
    </message>
</context>
<context>
    <name>FileIsSameDialog</name>
    <message>
        <location filename="../../FileIsSameDialog.cpp" line="145"/>
        <source>%name% - copy%suffix%</source>
        <translation>%name% - copia%suffix%</translation>
    </message>
    <message>
        <location filename="../../FileIsSameDialog.cpp" line="152"/>
        <source>%name% - copy (%number%)%suffix%</source>
        <translation>%name% - copia (%number%)%suffix%</translation>
    </message>
    <message>
        <location filename="../../FileIsSameDialog.cpp" line="225"/>
        <source>Error</source>
        <translation>Error</translation>
    </message>
    <message>
        <location filename="../../FileIsSameDialog.cpp" line="225"/>
        <source>Try rename with using special characters</source>
        <translation>Trate de cambiar el nombre con el uso de caracteres especiales</translation>
    </message>
</context>
<context>
    <name>FilterRules</name>
    <message>
        <location filename="../../FilterRules.ui" line="33"/>
        <source>Search:</source>
        <translation>Buscar:</translation>
    </message>
    <message>
        <location filename="../../FilterRules.ui" line="43"/>
        <source>Search type:</source>
        <translation>Tipo de búsqueda:</translation>
    </message>
    <message>
        <location filename="../../FilterRules.ui" line="51"/>
        <source>Raw text</source>
        <translation>texto Fuente</translation>
    </message>
    <message>
        <location filename="../../FilterRules.ui" line="56"/>
        <source>Simplified regex</source>
        <translation>Regex simplificado</translation>
    </message>
    <message>
        <location filename="../../FilterRules.ui" line="61"/>
        <source>Perl&apos;s regex</source>
        <translation>Perl&apos;s regex</translation>
    </message>
    <message>
        <location filename="../../FilterRules.ui" line="69"/>
        <source>Apply on:</source>
        <translation>Aplicar sobre:</translation>
    </message>
    <message>
        <location filename="../../FilterRules.ui" line="77"/>
        <source>File</source>
        <translation>Archivos</translation>
    </message>
    <message>
        <location filename="../../FilterRules.ui" line="82"/>
        <source>Folder</source>
        <translation>Carpeta</translation>
    </message>
    <message>
        <location filename="../../FilterRules.ui" line="87"/>
        <source>File and folder</source>
        <translation>Archivos y carpeta</translation>
    </message>
    <message>
        <location filename="../../FilterRules.ui" line="125"/>
        <source>The test string matches with the regex</source>
        <translation>La cadena de prueba coincide con la expresión regular</translation>
    </message>
    <message>
        <location filename="../../FilterRules.ui" line="102"/>
        <source>Checking</source>
        <translation>Verification</translation>
    </message>
    <message>
        <location filename="../../FilterRules.ui" line="115"/>
        <source>Test string:</source>
        <translation>Prueba de la cuerda:</translation>
    </message>
    <message>
        <location filename="../../FilterRules.ui" line="17"/>
        <source>Filters dialog</source>
        <translation>Filtros de diálogo</translation>
    </message>
    <message>
        <location filename="../../FilterRules.ui" line="95"/>
        <source>Whole string must match</source>
        <translation>Todo cadena debe coincidir</translation>
    </message>
    <message>
        <location filename="../../FilterRules.ui" line="108"/>
        <source>The regex is valid</source>
        <translation>La expresión regular es válido</translation>
    </message>
</context>
<context>
    <name>Filters</name>
    <message>
        <location filename="../../Filters.ui" line="14"/>
        <source>Filters</source>
        <translation>Filtros</translation>
    </message>
    <message>
        <location filename="../../Filters.ui" line="39"/>
        <source>Exclusion filters</source>
        <translation>Filtros de exclusión</translation>
    </message>
    <message>
        <location filename="../../Filters.ui" line="111"/>
        <source>Inclusion filters</source>
        <translation>Filtros de inclusión</translation>
    </message>
    <message>
        <location filename="../../Filters.ui" line="132"/>
        <source>None = Include all</source>
        <translation>Ninguno = Incluya todos los</translation>
    </message>
    <message>
        <location filename="../../Filters.cpp" line="94"/>
        <location filename="../../Filters.cpp" line="132"/>
        <source>Raw text</source>
        <translation>texto Fuente</translation>
    </message>
    <message>
        <location filename="../../Filters.cpp" line="97"/>
        <location filename="../../Filters.cpp" line="135"/>
        <source>Simplified regex</source>
        <translation>Simplificado regex</translation>
    </message>
    <message>
        <location filename="../../Filters.cpp" line="100"/>
        <location filename="../../Filters.cpp" line="138"/>
        <source>Perl&apos;s regex</source>
        <translation>Perl&apos;s regex</translation>
    </message>
    <message>
        <location filename="../../Filters.cpp" line="108"/>
        <location filename="../../Filters.cpp" line="146"/>
        <source>Only on file</source>
        <translation>Sólo en el archivo</translation>
    </message>
    <message>
        <location filename="../../Filters.cpp" line="111"/>
        <location filename="../../Filters.cpp" line="149"/>
        <source>Only on folder</source>
        <translation>Sólo en la carpeta</translation>
    </message>
    <message>
        <location filename="../../Filters.cpp" line="117"/>
        <location filename="../../Filters.cpp" line="155"/>
        <location filename="../../Filters.cpp" line="217"/>
        <location filename="../../Filters.cpp" line="256"/>
        <source>Full match</source>
        <translation>Partido completo</translation>
    </message>
</context>
<context>
    <name>FolderExistsDialog</name>
    <message>
        <location filename="../../FolderExistsDialog.cpp" line="91"/>
        <source>Folder already exists</source>
        <translation>Carpeta ya existe</translation>
    </message>
    <message>
        <location filename="../../FolderExistsDialog.cpp" line="172"/>
        <source>%name% - copy%suffix%</source>
        <translation>%name% - copia%suffix%</translation>
    </message>
    <message>
        <location filename="../../FolderExistsDialog.cpp" line="181"/>
        <source>%name% - copy (%number%)%suffix%</source>
        <translation>%name% - copia (%number%)%suffix%</translation>
    </message>
    <message>
        <location filename="../../FolderExistsDialog.cpp" line="248"/>
        <source>Error</source>
        <translation>Error</translation>
    </message>
    <message>
        <location filename="../../FolderExistsDialog.cpp" line="248"/>
        <source>Try rename with using special characters</source>
        <translation>Trate de cambiar el nombre con el uso de caracteres especiales</translation>
    </message>
</context>
<context>
    <name>ListThread</name>
    <message>
        <location filename="../../ListThreadListChange.cpp" line="242"/>
        <location filename="../../ListThreadListChange.cpp" line="413"/>
        <source>Unable do to move or copy item into wrong forced mode: %1</source>
        <translation>No se puede hacer para mover o copiar elemento en modo incorrecto obligado: %1</translation>
    </message>
    <message>
        <location filename="../../ListThreadListChange.cpp" line="249"/>
        <location filename="../../ListThreadListChange.cpp" line="420"/>
        <source>Unable to save the transfer list: %1</source>
        <translation>No se puede guardar la lista de transferencias: %1</translation>
    </message>
    <message>
        <location filename="../../ListThreadListChange.cpp" line="270"/>
        <source>Problem reading file, or file-size is 0</source>
        <translation>Problema al leer el archivo o archivos de tamaño es 0</translation>
    </message>
    <message>
        <location filename="../../ListThreadListChange.cpp" line="277"/>
        <source>Wrong header: &quot;%1&quot;</source>
        <translation>Encabezado incorrecto: &quot;%1&quot;</translation>
    </message>
    <message>
        <location filename="../../ListThreadListChange.cpp" line="286"/>
        <source>The transfer list is in mixed mode, but this instance is not in this mode</source>
        <translation>La lista de transferencia está en modo mixto, pero este caso no es de este modo</translation>
    </message>
    <message>
        <location filename="../../ListThreadListChange.cpp" line="295"/>
        <source>The transfer list is in copy mode, but this instance is not in this mode</source>
        <translation>La lista de transferencia está en el modo de copia, pero esta instancia no está en este modo</translation>
    </message>
    <message>
        <location filename="../../ListThreadListChange.cpp" line="301"/>
        <source>The transfer list is in move mode, but this instance is not in this mode</source>
        <translation>La lista de transferencia es el modo de desplazamiento, pero esta instancia no está en este modo</translation>
    </message>
    <message>
        <location filename="../../ListThreadListChange.cpp" line="365"/>
        <source>Some errors have been found during the line parsing</source>
        <translation>Algunos errores han sido encontrados durante el análisis de línea</translation>
    </message>
    <message>
        <location filename="../../ListThreadListChange.cpp" line="373"/>
        <source>Unable to open the transfer list: %1</source>
        <translation>No se puede abrir la lista de transferencias: %1</translation>
    </message>
</context>
<context>
    <name>MkPath</name>
    <message>
        <location filename="../../MkPath.cpp" line="187"/>
        <location filename="../../MkPath.cpp" line="210"/>
        <location filename="../../MkPath.cpp" line="315"/>
        <location filename="../../MkPath.cpp" line="363"/>
        <source>Unable to create the folder</source>
        <translation>No se puede crear la carpeta</translation>
    </message>
    <message>
        <location filename="../../MkPath.cpp" line="227"/>
        <source>The source folder don&apos;t exists</source>
        <translation>La carpeta de origen no existe</translation>
    </message>
    <message>
        <location filename="../../MkPath.cpp" line="304"/>
        <source>Unable to temporary rename the folder</source>
        <translation>No es posible cambiar el nombre de la carpeta temporal</translation>
    </message>
    <message>
        <location filename="../../MkPath.cpp" line="339"/>
        <source>Unable to reverse temporary rename for real move</source>
        <translation>No se puede revertir el cambio de nombre temporal para un movimiento real</translation>
    </message>
    <message>
        <location filename="../../MkPath.cpp" line="348"/>
        <source>Unable to do the final real move the folder</source>
        <translation>No se puede hacer el movimiento final real de la carpeta</translation>
    </message>
    <message>
        <location filename="../../MkPath.cpp" line="379"/>
        <source>Unable to move the folder</source>
        <translation>No se puede mover la carpeta</translation>
    </message>
    <message>
        <location filename="../../MkPath.cpp" line="385"/>
        <source>Unable to move the folder: errno: %1</source>
        <translation>No se puede mover la carpeta: errno: %1</translation>
    </message>
    <message>
        <location filename="../../MkPath.cpp" line="124"/>
        <location filename="../../MkPath.cpp" line="464"/>
        <source>Unable to remove</source>
        <translation>No se puede eliminar</translation>
    </message>
</context>
<context>
    <name>ReadThread</name>
    <message>
        <location filename="../../async/ReadThread.cpp" line="78"/>
        <source>Internal error, please report it!</source>
        <translation>¡Error interno, por favor repórtelo!</translation>
    </message>
    <message>
        <location filename="../../async/ReadThread.cpp" line="543"/>
        <source>Unable to read the source file: </source>
        <translation>No se puede leer el archivo fuente: </translation>
    </message>
    <message>
        <location filename="../../async/ReadThread.cpp" line="599"/>
        <source>File truncated during the read, possible data change</source>
        <translation>Archivo truncado durante la lectura, posible cambio de datos</translation>
    </message>
</context>
<context>
    <name>RenamingRules</name>
    <message>
        <location filename="../../RenamingRules.ui" line="35"/>
        <source>First renaming</source>
        <translation>En primer lugar el cambio de nombre</translation>
    </message>
    <message>
        <location filename="../../RenamingRules.ui" line="41"/>
        <source>%name% - copy%suffix%</source>
        <extracomment>%name% should not be translated</extracomment>
        <translation>%name% - copia%suffix%</translation>
    </message>
    <message>
        <location filename="../../RenamingRules.ui" line="57"/>
        <source>%name% - copy (%number%)%suffix%</source>
        <extracomment>%name%, %number% should not be translated</extracomment>
        <translation>%name% - copia (%number%)%suffix%</translation>
    </message>
    <message>
        <location filename="../../RenamingRules.ui" line="67"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Variables: &lt;span style=&quot; font-weight:600;&quot;&gt;%name%&lt;/span&gt; for the original file name, &lt;span style=&quot; font-weight:600;&quot;&gt;%number%&lt;/span&gt; for the extra number, &lt;span style=&quot; font-weight:600;&quot;&gt;%suffix%&lt;/span&gt; file suffix&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <extracomment>%name%, %number% should not be translated</extracomment>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Variables: &lt;span style=&quot; font-weight:600;&quot;&gt;%name%&lt;/span&gt; para el nombre del archivo original, &lt;span style=&quot; font-weight:600;&quot;&gt;%number%&lt;/span&gt; para el número extra, &lt;span style=&quot; font-weight:600;&quot;&gt;%suffix%&lt;/span&gt; sufijo de archivo&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../../RenamingRules.ui" line="51"/>
        <source>Second renaming</source>
        <translation>En segundo lugar el cambio de nombre</translation>
    </message>
    <message>
        <location filename="../../RenamingRules.ui" line="14"/>
        <source>Renaming rules</source>
        <translation>Reglas de Cambio de nombre</translation>
    </message>
    <message>
        <location filename="../../RenamingRules.cpp" line="46"/>
        <location filename="../../RenamingRules.cpp" line="71"/>
        <source>%1 - copy%2</source>
        <translation>%1 - copia%2</translation>
    </message>
    <message>
        <location filename="../../RenamingRules.cpp" line="50"/>
        <location filename="../../RenamingRules.cpp" line="84"/>
        <source>%1 - copy (%2)%3</source>
        <translation>%1 - copia (%2)%3</translation>
    </message>
</context>
<context>
    <name>ScanFileOrFolder</name>
    <message>
        <location filename="../../ScanFileOrFolder.cpp" line="331"/>
        <location filename="../../ScanFileOrFolder.cpp" line="681"/>
        <source>Blacklisted folder</source>
        <translation>Carpeta en la lista negra</translation>
    </message>
    <message>
        <location filename="../../ScanFileOrFolder.cpp" line="463"/>
        <location filename="../../ScanFileOrFolder.cpp" line="465"/>
        <source>%1 - copy</source>
        <translation>%1 - copia</translation>
    </message>
    <message>
        <location filename="../../ScanFileOrFolder.cpp" line="474"/>
        <location filename="../../ScanFileOrFolder.cpp" line="476"/>
        <source>%1 - copy (%2)</source>
        <translation>%1 - copia (%2)</translation>
    </message>
    <message>
        <location filename="../../ScanFileOrFolder.cpp" line="587"/>
        <location filename="../../ScanFileOrFolder.cpp" line="589"/>
        <source>%name% - copy</source>
        <translation>%name% - copia</translation>
    </message>
    <message>
        <location filename="../../ScanFileOrFolder.cpp" line="598"/>
        <location filename="../../ScanFileOrFolder.cpp" line="600"/>
        <source>%name% - copy (%number%)</source>
        <translation>%name% - copia (%number%)</translation>
    </message>
    <message>
        <location filename="../../ScanFileOrFolder.cpp" line="691"/>
        <location filename="../../ScanFileOrFolder.cpp" line="695"/>
        <source>Problem with folder read</source>
        <translation>Problema con la carpeta leída</translation>
    </message>
</context>
<context>
    <name>TransferThread</name>
    <message>
        <location filename="../../TransferThread.cpp" line="628"/>
        <source>%name% - copy%suffix%</source>
        <translation>%name% - copia%suffix%</translation>
    </message>
    <message>
        <location filename="../../TransferThread.cpp" line="635"/>
        <source>%name% - copy (%number%)%suffix%</source>
        <translation>%name% - copia (%number%)%suffix%</translation>
    </message>
    <message>
        <location filename="../../TransferThread.cpp" line="663"/>
        <location filename="../../TransferThread.cpp" line="904"/>
        <source>File not found</source>
        <translation>Archivo no encontrado</translation>
    </message>
    <message>
        <location filename="../../TransferThread.cpp" line="904"/>
        <location filename="../../TransferThread.cpp" line="940"/>
        <source>Unable to change the date</source>
        <translation>No se puede cambiar la fecha</translation>
    </message>
    <message>
        <location filename="../../TransferThread.cpp" line="188"/>
        <source>Try rename with using special characters</source>
        <translation>Trate de cambiar el nombre con el uso de caracteres especiales</translation>
    </message>
</context>
<context>
    <name>TransferThreadAsync</name>
    <message>
        <location filename="../../async/TransferThreadAsync.cpp" line="342"/>
        <source>Wrong modification date or unable to get it, you can disable time transfer to do it</source>
        <translation>Fecha de modificación incorrecta o incapaz de obtenerla, puede desactivar la transferencia de tiempo para hacerlo</translation>
    </message>
    <message>
        <location filename="../../async/TransferThreadAsync.cpp" line="436"/>
        <location filename="../../async/TransferThreadAsync.cpp" line="454"/>
        <source>Unable to create the destination folder: </source>
        <translation>No se puede crear la carpeta de destino: </translation>
    </message>
    <message>
        <location filename="../../async/TransferThreadAsync.cpp" line="439"/>
        <location filename="../../async/TransferThreadAsync.cpp" line="456"/>
        <source>Unable to create the destination folder, errno: %1</source>
        <translation>No se puede crear la carpeta de destino, errno: %1</translation>
    </message>
</context>
<context>
    <name>WriteThread</name>
    <message>
        <location filename="../../async/WriteThread.cpp" line="138"/>
        <source>Path resolution error (Empty path)</source>
        <translation>Error de resolución de ruta (ruta vacía)</translation>
    </message>
    <message>
        <location filename="../../async/WriteThread.cpp" line="167"/>
        <location filename="../../async/WriteThread.cpp" line="200"/>
        <source>Unable to create the destination folder: </source>
        <translation>No se puede crear la carpeta de destino: </translation>
    </message>
    <message>
        <location filename="../../async/WriteThread.cpp" line="178"/>
        <location filename="../../async/WriteThread.cpp" line="202"/>
        <source>Unable to create the destination folder, errno: %1</source>
        <translation>No se puede crear la carpeta de destino, errno: %1</translation>
    </message>
    <message>
        <location filename="../../async/WriteThread.cpp" line="464"/>
        <source>Internal error, please report it!</source>
        <translation>¡Error interno, por favor repórtelo!</translation>
    </message>
</context>
<context>
    <name>copyEngineOptions</name>
    <message>
        <location filename="../../copyEngineOptions.ui" line="44"/>
        <source>Transfer</source>
        <translation>Transferencia</translation>
    </message>
    <message>
        <location filename="../../copyEngineOptions.ui" line="63"/>
        <source>Move the whole folder</source>
        <translation>Mueva la carpeta completa</translation>
    </message>
    <message>
        <location filename="../../copyEngineOptions.ui" line="97"/>
        <source>Transfer the file rights</source>
        <translation>Transferencia de los derechos de archivo</translation>
    </message>
    <message>
        <location filename="../../copyEngineOptions.ui" line="76"/>
        <source>Keep the file date</source>
        <translation>Mantener la fecha de archivo</translation>
    </message>
    <message>
        <location filename="../../copyEngineOptions.ui" line="114"/>
        <source>Create full path if not exists</source>
        <translation>Crear ruta completa si no existe</translation>
    </message>
    <message>
        <location filename="../../copyEngineOptions.ui" line="138"/>
        <source>Checksum</source>
        <translation>Suma de comprobación</translation>
    </message>
    <message>
        <location filename="../../copyEngineOptions.ui" line="83"/>
        <source>Auto start</source>
        <translation>Inicio automático</translation>
    </message>
    <message>
        <location filename="../../copyEngineOptions.ui" line="154"/>
        <source>Error and collision</source>
        <translation>Error y de la colisión</translation>
    </message>
    <message>
        <location filename="../../copyEngineOptions.ui" line="160"/>
        <source>When folder error</source>
        <translation>Cuando el error carpeta</translation>
    </message>
    <message>
        <location filename="../../copyEngineOptions.ui" line="170"/>
        <source>When file error</source>
        <translation>Cuando archivo error</translation>
    </message>
    <message>
        <location filename="../../copyEngineOptions.ui" line="196"/>
        <source>When file collision</source>
        <translation>Cuando archivo colisión</translation>
    </message>
    <message>
        <location filename="../../copyEngineOptions.ui" line="239"/>
        <source>Overwrite if not same size</source>
        <translation>Sobrescribir si no es del mismo tamaño</translation>
    </message>
    <message>
        <location filename="../../copyEngineOptions.ui" line="244"/>
        <source>Overwrite if modification date differs</source>
        <translation>Sobrescribir si la fecha de modificación difiere</translation>
    </message>
    <message>
        <location filename="../../copyEngineOptions.ui" line="266"/>
        <source>When folder collision</source>
        <translation>Cuando la colisión carpeta</translation>
    </message>
    <message>
        <location filename="../../copyEngineOptions.ui" line="297"/>
        <source>Check if destination folder exists</source>
        <translation>Compruebe si existe la carpeta de destino</translation>
    </message>
    <message>
        <location filename="../../copyEngineOptions.ui" line="304"/>
        <source>Renaming rules</source>
        <translation>Reglas de Cambio de nombre</translation>
    </message>
    <message>
        <location filename="../../copyEngineOptions.ui" line="324"/>
        <source>Delete partially transferred files</source>
        <translation>Eliminar archivos parcialmente transferidos</translation>
    </message>
    <message>
        <location filename="../../copyEngineOptions.ui" line="337"/>
        <source>Rename the original destination</source>
        <translation>Cambie el nombre del destino original</translation>
    </message>
    <message>
        <location filename="../../copyEngineOptions.ui" line="368"/>
        <source>Performance</source>
        <translation>Rendimiento</translation>
    </message>
    <message>
        <location filename="../../copyEngineOptions.ui" line="387"/>
        <source>Inode threads</source>
        <translation>Inode threads</translation>
    </message>
    <message>
        <location filename="../../copyEngineOptions.ui" line="397"/>
        <location filename="../../copyEngineOptions.ui" line="413"/>
        <source>MB</source>
        <translation>MB</translation>
    </message>
    <message>
        <location filename="../../copyEngineOptions.ui" line="429"/>
        <source>Uncheck this under Windows create problem</source>
        <translation>Desmarca esto en Windows crear problema</translation>
    </message>
    <message>
        <location filename="../../copyEngineOptions.ui" line="436"/>
        <source>OS Buffer</source>
        <translation>Búfer del SO</translation>
    </message>
    <message>
        <location filename="../../copyEngineOptions.ui" line="456"/>
        <source>Disable parallel transfer when are different devices</source>
        <translation>Deshabilitar la transferencia paralela cuando hay diferentes dispositivos</translation>
    </message>
    <message>
        <location filename="../../copyEngineOptions.ui" line="463"/>
        <source>Buffer for different device</source>
        <translation>Búfer para diferentes dispositivos</translation>
    </message>
    <message>
        <location filename="../../copyEngineOptions.ui" line="470"/>
        <source>OS FLags</source>
        <translation>Banderas de SO</translation>
    </message>
    <message>
        <location filename="../../copyEngineOptions.ui" line="477"/>
        <source>Buffer for same device</source>
        <translation>Búfer para el mismo dispositivo</translation>
    </message>
    <message>
        <location filename="../../copyEngineOptions.ui" line="484"/>
        <source>OS native copy (disable speed limitation)</source>
        <translation>Copia nativa del sistema operativo (deshabilitar la limitación de velocidad)</translation>
    </message>
    <message>
        <location filename="../../copyEngineOptions.ui" line="514"/>
        <source>Misc</source>
        <translation>Misc</translation>
    </message>
    <message>
        <location filename="../../copyEngineOptions.ui" line="520"/>
        <source>Check the disk space</source>
        <translation>Compruebe el espacio en disco</translation>
    </message>
    <message>
        <location filename="../../copyEngineOptions.ui" line="530"/>
        <source>Use this folder when destination is not set</source>
        <translation>Use esta carpeta cuando el destino no esté configurado</translation>
    </message>
    <message>
        <location filename="../../copyEngineOptions.ui" line="542"/>
        <source>Browse</source>
        <translation>Busque</translation>
    </message>
    <message>
        <location filename="../../copyEngineOptions.ui" line="564"/>
        <source>Filters</source>
        <translation>Filtros</translation>
    </message>
</context>
<context>
    <name>fileErrorDialog</name>
    <message>
        <location filename="../../fileErrorDialog.ui" line="14"/>
        <source>Error with file</source>
        <translation>Error con el archivo</translation>
    </message>
    <message>
        <location filename="../../fileErrorDialog.ui" line="20"/>
        <source>Error</source>
        <translation>Error</translation>
    </message>
    <message>
        <location filename="../../fileErrorDialog.ui" line="59"/>
        <source>Size</source>
        <translation>Tamaño</translation>
    </message>
    <message>
        <location filename="../../fileErrorDialog.ui" line="76"/>
        <source>Modified</source>
        <translation>Modificado</translation>
    </message>
    <message>
        <location filename="../../fileErrorDialog.ui" line="93"/>
        <source>File name</source>
        <translation>Nombre de archivo</translation>
    </message>
    <message>
        <location filename="../../fileErrorDialog.ui" line="110"/>
        <source>Destination</source>
        <translation>Destino</translation>
    </message>
    <message>
        <location filename="../../fileErrorDialog.ui" line="127"/>
        <source>Folder</source>
        <translation>Carpeta</translation>
    </message>
    <message>
        <location filename="../../fileErrorDialog.ui" line="173"/>
        <source>&amp;Always perform this action</source>
        <translation>&amp;Siempre realice esta acción</translation>
    </message>
    <message>
        <location filename="../../fileErrorDialog.ui" line="193"/>
        <source>Try in with elevated privileges</source>
        <translation>Pruebe con privilegios elevados</translation>
    </message>
    <message>
        <location filename="../../fileErrorDialog.ui" line="200"/>
        <source>Put to bottom</source>
        <translation>Ponga a abajo</translation>
    </message>
    <message>
        <location filename="../../fileErrorDialog.ui" line="207"/>
        <source>Retry</source>
        <translation>Reintentar</translation>
    </message>
    <message>
        <location filename="../../fileErrorDialog.ui" line="214"/>
        <source>&amp;Skip</source>
        <translation>&amp;Omitir</translation>
    </message>
    <message>
        <location filename="../../fileErrorDialog.ui" line="221"/>
        <source>&amp;Cancel</source>
        <translation>Cancelar</translation>
    </message>
</context>
<context>
    <name>fileExistsDialog</name>
    <message>
        <location filename="../../fileExistsDialog.ui" line="14"/>
        <source>The file exists</source>
        <translation>El archivo ya existe</translation>
    </message>
    <message>
        <location filename="../../fileExistsDialog.ui" line="34"/>
        <source>Source</source>
        <translation>Fuente</translation>
    </message>
    <message>
        <location filename="../../fileExistsDialog.ui" line="50"/>
        <source>Destination</source>
        <translation>Destino</translation>
    </message>
    <message>
        <location filename="../../fileExistsDialog.ui" line="82"/>
        <location filename="../../fileExistsDialog.ui" line="170"/>
        <source>Size</source>
        <translation>Tamaño</translation>
    </message>
    <message>
        <location filename="../../fileExistsDialog.ui" line="99"/>
        <location filename="../../fileExistsDialog.ui" line="187"/>
        <source>Modified</source>
        <translation>Modificado</translation>
    </message>
    <message>
        <location filename="../../fileExistsDialog.ui" line="116"/>
        <location filename="../../fileExistsDialog.ui" line="204"/>
        <source>File name</source>
        <translation>Nombre de archivo</translation>
    </message>
    <message>
        <location filename="../../fileExistsDialog.ui" line="133"/>
        <location filename="../../fileExistsDialog.ui" line="221"/>
        <source>Folder</source>
        <translation>Carpeta</translation>
    </message>
    <message>
        <location filename="../../fileExistsDialog.ui" line="277"/>
        <source>Suggest new &amp;name</source>
        <translation>Sugerir nuevo &amp;nombre</translation>
    </message>
    <message>
        <location filename="../../fileExistsDialog.ui" line="288"/>
        <source>&amp;Always perform this action</source>
        <translation>&amp;Siempre realice esta acción</translation>
    </message>
    <message>
        <location filename="../../fileExistsDialog.ui" line="341"/>
        <source>Overwrite if source newer than destination</source>
        <translation>Sobrescribir si la fuente es más nueva que el destino</translation>
    </message>
    <message>
        <location filename="../../fileExistsDialog.ui" line="346"/>
        <location filename="../../fileExistsDialog.ui" line="349"/>
        <source>Overwrite if modification date differs</source>
        <translation>Sobrescribir si la fecha de modificación difiere</translation>
    </message>
    <message>
        <location filename="../../fileExistsDialog.ui" line="354"/>
        <source>Overwrite if source older than destination</source>
        <translation>Sobrescribir si la fuente es más antigua que el destino</translation>
    </message>
    <message>
        <location filename="../../fileExistsDialog.ui" line="357"/>
        <source>Overwrite if destination older</source>
        <translation>Sobrescribir si el destino es más antiguo</translation>
    </message>
    <message>
        <location filename="../../fileExistsDialog.ui" line="362"/>
        <location filename="../../fileExistsDialog.ui" line="365"/>
        <source>Overwrite if not same size</source>
        <translation>Sobrescribir si no es del mismo tamaño</translation>
    </message>
    <message>
        <location filename="../../fileExistsDialog.ui" line="370"/>
        <location filename="../../fileExistsDialog.ui" line="373"/>
        <source>Overwrite if not same size and date</source>
        <translation>Sobrescribir si no es del mismo tamaño y fecha</translation>
    </message>
    <message>
        <location filename="../../fileExistsDialog.ui" line="308"/>
        <source>&amp;Rename</source>
        <translation>&amp;Cambiar el nombre</translation>
    </message>
    <message>
        <location filename="../../fileExistsDialog.ui" line="315"/>
        <source>&amp;Overwrite</source>
        <translation>&amp;Sobrescribir</translation>
    </message>
    <message>
        <location filename="../../fileExistsDialog.ui" line="325"/>
        <source>&amp;Skip</source>
        <translation>&amp;Omitir</translation>
    </message>
    <message>
        <location filename="../../fileExistsDialog.ui" line="332"/>
        <source>&amp;Cancel</source>
        <translation>Ca&amp;ncelar</translation>
    </message>
</context>
<context>
    <name>fileIsSameDialog</name>
    <message>
        <location filename="../../fileIsSameDialog.ui" line="40"/>
        <source>Size</source>
        <translation>Tamaño</translation>
    </message>
    <message>
        <location filename="../../fileIsSameDialog.ui" line="110"/>
        <source>Modified</source>
        <translation>Modificado</translation>
    </message>
    <message>
        <location filename="../../fileIsSameDialog.ui" line="70"/>
        <source>File name</source>
        <translation>Nombre de archivo</translation>
    </message>
    <message>
        <location filename="../../fileIsSameDialog.ui" line="14"/>
        <source>The source and destination are same</source>
        <translation>El origen y el destino son los mismos</translation>
    </message>
    <message>
        <location filename="../../fileIsSameDialog.ui" line="90"/>
        <source>Folder</source>
        <translation>Carpeta</translation>
    </message>
    <message>
        <location filename="../../fileIsSameDialog.ui" line="159"/>
        <source>Suggest new &amp;name</source>
        <translation>Sugerir nuevo nombre</translation>
    </message>
    <message>
        <location filename="../../fileIsSameDialog.ui" line="170"/>
        <source>&amp;Always perform this action</source>
        <translation>&amp;Siempre realice esta acción</translation>
    </message>
    <message>
        <location filename="../../fileIsSameDialog.ui" line="190"/>
        <source>&amp;Rename</source>
        <translation>Cambiar el nombre</translation>
    </message>
    <message>
        <location filename="../../fileIsSameDialog.ui" line="197"/>
        <source>&amp;Skip</source>
        <translation>Omitir</translation>
    </message>
    <message>
        <location filename="../../fileIsSameDialog.ui" line="204"/>
        <source>&amp;Cancel</source>
        <translation>Cancelar</translation>
    </message>
</context>
<context>
    <name>folderExistsDialog</name>
    <message>
        <location filename="../../folderExistsDialog.ui" line="34"/>
        <source>Source</source>
        <translation>Fuente</translation>
    </message>
    <message>
        <location filename="../../folderExistsDialog.ui" line="50"/>
        <source>Destination</source>
        <translation>Destino</translation>
    </message>
    <message>
        <location filename="../../folderExistsDialog.ui" line="14"/>
        <source>The source and destination is identical</source>
        <translation>La fuente y el destino es idéntica</translation>
    </message>
    <message>
        <location filename="../../folderExistsDialog.ui" line="82"/>
        <location filename="../../folderExistsDialog.ui" line="150"/>
        <source>Modified</source>
        <translation>Modificado</translation>
    </message>
    <message>
        <location filename="../../folderExistsDialog.ui" line="99"/>
        <location filename="../../folderExistsDialog.ui" line="160"/>
        <source>Folder name</source>
        <translation>Nombre de la carpeta</translation>
    </message>
    <message>
        <location filename="../../folderExistsDialog.ui" line="116"/>
        <location filename="../../folderExistsDialog.ui" line="184"/>
        <source>Folder</source>
        <translation>Carpeta</translation>
    </message>
    <message>
        <location filename="../../folderExistsDialog.ui" line="227"/>
        <source>Suggest new &amp;name</source>
        <translation>Sugerir nuevo nombre</translation>
    </message>
    <message>
        <location filename="../../folderExistsDialog.ui" line="238"/>
        <source>&amp;Always perform this action</source>
        <translation>&amp;Siempre realice esta acción</translation>
    </message>
    <message>
        <location filename="../../folderExistsDialog.ui" line="245"/>
        <source>&amp;Rename</source>
        <translation>Cambiar el nombre</translation>
    </message>
    <message>
        <location filename="../../folderExistsDialog.ui" line="252"/>
        <source>Merge</source>
        <translation>Unir</translation>
    </message>
    <message>
        <location filename="../../folderExistsDialog.ui" line="259"/>
        <source>Skip</source>
        <translation>Omitir</translation>
    </message>
    <message>
        <location filename="../../folderExistsDialog.ui" line="266"/>
        <source>&amp;Cancel</source>
        <translation>Cancelar</translation>
    </message>
</context>
</TS>
